@@ -1,4 +1,5 @@
 import logging
+from abc import ABCMeta
 from typing import Any, Dict, List, Optional
 
 import sqlalchemy as sa
@@ -17,7 +18,7 @@ from sqlalchemy.sql.expression import ColumnCollection
 logger = logging.getLogger("dy")
 
 
-class Block(DyBlock):
+class Block(DyBlock, metaclass=ABCMeta):
 
     def init(self, context: Optional[Context] = None):
         logger.debug(f"Initializing {self.get_block_name()}")
