@@ -1,5 +1,6 @@
 import logging
-from typing import Any, Dict, List
+from abc import ABCMeta
+from typing import Any, Dict, List, Optional
 
 from datayoga_core.block import Block as DyBlock
 from datayoga_core.context import Context
@@ -7,8 +8,9 @@ from datayoga_core.context import Context
 logger = logging.getLogger(__name__)
 
 
-class Block(DyBlock):
-    def init(self):
+class Block(DyBlock, metaclass=ABCMeta):
+
+    def init(self, context: Optional[Context] = None):
         pass
 
     def run(self, data: List[Dict[str, Any]], context: Context = None) -> List[Dict[str, Any]]:
