@@ -1,6 +1,7 @@
 import json
 import logging
 import sys
+from abc import ABCMeta
 from typing import Any, Dict, List, Optional
 
 from datayoga_core import utils
@@ -11,7 +12,7 @@ from datayoga_core.result import BlockResult
 logger = logging.getLogger("dy")
 
 
-class Block(DyBlock):
+class Block(DyBlock, metaclass=ABCMeta):
 
     def init(self, context: Optional[Context] = None):
         logger.debug(f"Initializing {self.get_block_name()}")
