@@ -1,18 +1,16 @@
-import logging
 from abc import abstractmethod
 from typing import Any, Dict, Generator, List, TypedDict
 
 from .block import Block
 
-logger = logging.getLogger("dy")
-Message = TypedDict("Message", msg_id=str, value=Dict[str, Any])
+Message = TypedDict("Message", {"msg_id": str, "value": Dict[str, Any]})
 
 
 class Producer(Block):
 
     @abstractmethod
     def produce(self) -> Generator[Message, None, None]:
-        """ Produces data
+        """Produces data
 
         Returns:
             Generator[Message]: Produced data
@@ -20,7 +18,7 @@ class Producer(Block):
         raise NotImplementedError
 
     def ack(self, msg_ids: List[str]):
-        """ Sends acknowledge for the message IDs of the records that have been processed
+        """Sends acknowledge for the message IDs of the records that have been processed
 
         Args:
             msg_ids (List[str]): Message IDs
